import { Component } from '@angular/core';
import { AuditSymbol } from '../models/audit-symbols';

@Component({
  selector: 'cse-audit-legend',
  templateUrl: './audit-legend.component.html',
  styleUrls: ['./audit-legend.component.scss'],
})
export class AuditLegendComponent {
  public auditCourseColumns: string[] = ['symbol', 'description'];
  public legends: { title: string, symbols: AuditSymbol[] }[] = [
    {
      title: 'Course Symbols',
      symbols: [
        { type: 'text', text: '>D', tooltip: 'Duplicate course - retains GPA effect' },
        { type: 'text', text: '>R', tooltip: 'Repeatable course' },
        { type: 'text', text: '>S', tooltip: 'Credit split between requirements' },
        { type: 'text', text: '>R', tooltip: 'Repeatable course' },
        { type: 'text', text: '(R)', tooltip: 'Required course' },
        { type: 'text', text: '(X)', tooltip: 'Original course value' },
      ]
    },
    {
      title: 'Grade Symbols',
      symbols: [
        { type: 'text', text: 'EIP', tooltip: 'Extended incomplete' },
        { type: 'text', text: 'CR', tooltip: 'Credit (credit/no credit courses)' },
        { type: 'text', text: 'HS', tooltip: 'High school unit' },
        { type: 'text', text: 'IN', tooltip: 'Incomplete (credit/no credit courses)' },
        { type: 'text', text: 'INP', tooltip: 'In-progress course (current term)' },
        { type: 'text', text: 'IP', tooltip: 'Incomplete' },
        { type: 'text', text: 'N', tooltip: 'No credit (credit/no credit courses)' },
        { type: 'text', text: 'NR', tooltip: 'Not reported' },
        { type: 'text', text: 'NW', tooltip: 'No work' },
        { type: 'text', text: 'PL', tooltip: 'Planned course' },
        { type: 'text', text: 'PP', tooltip: 'Progress' },
        { type: 'text', text: 'PS', tooltip: 'Mock/pseudo course' },
        { type: 'text', text: 'Q', tooltip: 'Question on credits or honors' },
        { type: 'text', text: 'S', tooltip: 'Satisfactory (pass/fail and audit courses)' },
        { type: 'text', text: 'T', tooltip: 'Transfer/test/advanced standing course' },
        { type: 'text', text: 'U', tooltip: 'Unsatisfactory (pass/fail courses)' },
      ]
    },
    {
      title: 'Requirement / Sub-requirement Information',
      symbols: [
        { type: 'text', text: 'OK', tooltip: 'Requirement complete' },
        { type: 'text', text: 'NO', tooltip: 'Requirement not complete' },
        { type: 'text', text: 'IP', tooltip: 'Requirement uses in-progress credit/courses' },
        { type: 'text', text: 'IN-P', tooltip: 'Sub-requirement uses in progress credit/courses' },
        { type: 'text', text: 'PL', tooltip: 'Requirement/sub-requirement uses planned course' },
        { type: 'text', text: 'R', tooltip: 'Required sub-requirement (mandatory)' },
        { type: 'text', text: '<>', tooltip: 'Optional/other requirement in OR\'d set complete' },
        { type: 'icon', text: '+', icon: 'check', tooltip: 'Sub-requirement complete', slug: 'complete-sub' },
        { type: 'icon', text: '-', icon: 'close', tooltip: 'Sub-requirement not complete', slug: 'not-complete-sub' },
        { type: 'text', text: '*', tooltip: 'Optional sub-requirement, courses assigned' },
        { type: 'text', text: ' ', tooltip: 'Optional sub-requirement, no courses assigned' },
      ]
    },
    {
      title: 'Exception Symbols',
      symbols: [
        { type: 'text', text: 'AC', tooltip: 'Course approved for requirement/sub-requirement', },
        { type: 'text', text: 'IC', tooltip: 'Course inserted into requirement/sub-requirement', },
        { type: 'text', text: 'EC', tooltip: 'Course exchanged for specified course' },
        { type: 'text', text: 'FC', tooltip: 'Course forced into requirement/sub-requirement', },
        { type: 'text', text: 'CM', tooltip: 'Course modified' },
        { type: 'text', text: 'CY', tooltip: 'Catalog year modified' },
        { type: 'text', text: 'DC', tooltip: 'Course deleted from requirement/sub-requirement', },
        { type: 'text', text: 'RM', tooltip: 'Requirement modified' },
        { type: 'text', text: 'WC', tooltip: 'Waive course' },
        { type: 'text', text: 'WP', tooltip: 'Waive mock/pseudo course' },
      ]
    }
  ];
}
